@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2003 Zope Corporation and Contributors.
+# Copyright (c) 2003 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,8 +12,6 @@
 #
 ##############################################################################
 """Test HTTP PUT verb
-
-$Id: test_put.py 116497 2010-09-17 12:04:44Z icemac $
 """
 from unittest import TestCase, TestSuite, makeSuite
 from StringIO import StringIO
@@ -116,6 +114,19 @@ class TestNullPUT(TestCase):
         # Check HTTP Response
         self.assertEqual(request.response.getStatus(), 201)
 
+    def test_put_on_invalid_container_raises_MethodNotAllowed(self):
+        import zope.publisher.interfaces.http
+
+        request = TestRequest(StringIO(),
+                              {'CONTENT_TYPE': 'test/foo',
+                               'CONTENT_LENGTH': '0',
+                               })
+        null = zope.app.http.put.NullResource(rootFolder(), 'spam.txt')
+        put = zope.app.http.put.NullPUT(null, request)
+        self.assertRaises(zope.publisher.interfaces.http.MethodNotAllowed,
+                          put.PUT)
+
+
 class TestFilePUT(TestCase):
     layer = BrowserLayer(zope.app.http)
 
@@ -151,6 +162,19 @@ class TestFilePUT(TestCase):
         # Check HTTP Response
         self.assertEqual(request.response.getStatus(), 200)
 
+    def test_put_on_invalid_file_raises_MethodNotAllowed(self):
+        import zope.publisher.interfaces.http
+
+        file = object()
+        request = TestRequest(StringIO(),
+                              {'CONTENT_TYPE': 'test/foo',
+                               'CONTENT_LENGTH': '0',
+                               })
+        put = zope.app.http.put.FilePUT(file, request)
+        self.assertRaises(zope.publisher.interfaces.http.MethodNotAllowed,
+                          put.PUT)
+
+
 def test_suite():
     return TestSuite((
         makeSuite(TestFilePUT),
